# [Changelog](https://github.com/michaeljoseph/pyconza2014/releases)

## [0.1.6](https://github.com/michaeljoseph/pyconza2014/compare/0.1.4...0.1.6)

* [a92984f](https://github.com/michaeljoseph/pyconza2014/commit/a92984f) Linting
* [72682eb](https://github.com/michaeljoseph/pyconza2014/commit/72682eb) py.test in travis-solo

## [0.1.4](https://github.com/michaeljoseph/pyconza2014/compare/0.1.3...0.1.4)

* [1ac97be](https://github.com/michaeljoseph/pyconza2014/commit/1ac97be) Add tox

## [0.1.3](https://github.com/michaeljoseph/pyconza2014/compare/0.1.2...0.1.3)

* [9b9431f](https://github.com/michaeljoseph/pyconza2014/commit/9b9431f) michaeljoseph/ccc template updates
* [7d2ca97](https://github.com/michaeljoseph/pyconza2014/commit/7d2ca97) Be more specific
* [553e57d](https://github.com/michaeljoseph/pyconza2014/commit/553e57d) Rm pyc
* [a656c12](https://github.com/michaeljoseph/pyconza2014/commit/a656c12) "0.1.0"
* [d89ff3a](https://github.com/michaeljoseph/pyconza2014/commit/d89ff3a) Rm egg-info
* [61e0426](https://github.com/michaeljoseph/pyconza2014/commit/61e0426) "0.0.2"
* [bf16a3d](https://github.com/michaeljoseph/pyconza2014/commit/bf16a3d) Init

## [0.1.2](https://github.com/michaeljoseph/pyconza2014/compare/0.1.1...0.1.2)

* [9b9431f](https://github.com/michaeljoseph/pyconza2014/commit/9b9431f) michaeljoseph/ccc template updates
* [7d2ca97](https://github.com/michaeljoseph/pyconza2014/commit/7d2ca97) Be more specific
* [553e57d](https://github.com/michaeljoseph/pyconza2014/commit/553e57d) Rm pyc
* [a656c12](https://github.com/michaeljoseph/pyconza2014/commit/a656c12) "0.1.0"
* [d89ff3a](https://github.com/michaeljoseph/pyconza2014/commit/d89ff3a) Rm egg-info
* [61e0426](https://github.com/michaeljoseph/pyconza2014/commit/61e0426) "0.0.2"
* [bf16a3d](https://github.com/michaeljoseph/pyconza2014/commit/bf16a3d) Init

## [0.1.1](https://github.com/michaeljoseph/pyconza2014/compare/0.1.0...0.1.1)

* [9b9431f](https://github.com/michaeljoseph/pyconza2014/commit/9b9431f) michaeljoseph/ccc template updates
* [7d2ca97](https://github.com/michaeljoseph/pyconza2014/commit/7d2ca97) Be more specific
* [553e57d](https://github.com/michaeljoseph/pyconza2014/commit/553e57d) Rm pyc

## [0.1.0](https://github.com/michaeljoseph/pyconza2014/compare/0.0.2...0.1.0)

* [d89ff3a](https://github.com/michaeljoseph/pyconza2014/commit/d89ff3a) Rm egg-info

## [0.0.2](https://github.com/michaeljoseph/pyconza2014/compare/0.0.1...0.0.2)

* [bf16a3d](https://github.com/michaeljoseph/pyconza2014/commit/bf16a3d) Init

## 0.0.1

* This version is first.